package gui;

import java.awt.Component;
import java.awt.Font;

import javax.swing.JTable;
import javax.swing.table.DefaultTableCellRenderer;

import static gui.ScoreboardRenderer.fontSize;

/**
 * Subclass of DefaultTableCellRenderer which facilitates different colored rows.  This renderer
 * should only be used on pairs of columns in which the first column stores a team name.
 *
 * @author Michael Gebauer
 */
public class RankingRenderer extends DefaultTableCellRenderer {

  static final long serialVersionUID = 20050112L;

  /**
   * Identical to the superclass implementation except rows are colored according to
   * team name.
   */
    public Component getTableCellRendererComponent
        (JTable table, Object value, boolean isSelected, boolean hasFocus, int row, int col)
    {
        Component cell = super.getTableCellRendererComponent(table,value,isSelected,hasFocus,row,col);
        Team team;

        // Since this renderer should only be used for pairs of columns, there
        // are two possible cases: either this column holds a team name or the column to
        // the left of this one does.  If this column holds a team name...
        if (table.getModel().getValueAt(row,col) instanceof Team) {
          team = (Team) table.getModel().getValueAt(row,col);
          cell.setBackground(team.getRowColor());
          setBorder(new ColumnBorder());
        }
        // else the column to the left must hold the team name.  So get the team name
        // from the column to the left...
        else {
          team = (Team) table.getModel().getValueAt(row,col-1);
          cell.setBackground(team.getRowColor());
        }

        // set the font
        cell.setFont(cell.getFont().deriveFont(Font.BOLD,fontSize));
    return cell;
    }
}

//  LocalWords:  DefaultTableCellRenderer
