package gui;

import static gui.UpopVote.MAX_TEAM_SIZE;

import java.awt.Dimension;

import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.ScrollPaneConstants;

import scorekeeping.Question;

/**
 * Scoreboard is a GUI component with multiple functions in the UpopVote
 * game.  The functions include: listing team names, displaying IDs of
 * participants needing to vote, displaying scores, displaying score
 * summaries, and displaying improvement rankings.  A JTable is used
 * to accomplish this.  The table model used is a ScoreboardModel.
 *
 * @author Michael Gebauer
 */
public class Scoreboard extends JScrollPane {

  static final long serialVersionUID = 20050112L;

  // True when the "most improved" columns are being displayed.
  // Primarily this is in round two of UpopVote
  public boolean showMostImproved;

  public JTable table = new JTable();
  public ScoreboardModel model = new ScoreboardModel();

  public Scoreboard() {
    super();

    table.setModel(model);

    this.setViewportView(table);
    table.setIntercellSpacing(new Dimension(0,0));

    table.setDefaultRenderer(Object.class, new ScoreboardRenderer());

    int firstScoringColumn = MAX_TEAM_SIZE+1;
    int lastScoringColumn = model.getColumnCount()-1;
    for (int col=firstScoringColumn; col<=lastScoringColumn; col++) {
      String columnName = model.getColumnName(col);
      table.getColumn(columnName).setCellRenderer(new RankingRenderer());
    }

    table.setRowHeight(20);
    Dimension preferredSize = getViewport().getViewSize();
    preferredSize.setSize(preferredSize.width,preferredSize.height+25);
    this.setPreferredSize(preferredSize);
    this.setVerticalScrollBarPolicy(ScrollPaneConstants.VERTICAL_SCROLLBAR_NEVER);

    // Set the width of the columns containing IDs to 1.  This
    // causes the columns to be small.
    for (int i=1; i<=MAX_TEAM_SIZE; i++)
      table.getColumn(table.getColumnName(i)).setPreferredWidth(1);
    // Likewise for the score columns
    table.getColumn(table.getColumnName(firstScoringColumn+1)).setPreferredWidth(1);

  }

  public void displayAllTransmitterIDs() {
    model.displayAllTransmitterIDs();
  }

  // clear the id section
  public void clearIdSection() {
    model.clearIdSection();
  }

  public void displayMostImproved() {
    model.displayMostImproved();

    // update column renderers
    int firstScoringColumn = MAX_TEAM_SIZE+1;
    int lastScoringColumn = model.getColumnCount()-1;
    for (int col=firstScoringColumn; col<=lastScoringColumn; col++) {
      String columnName;
      columnName = model.getColumnName(col);
      table.getColumn(columnName).setCellRenderer(new RankingRenderer());
    }

    // Set the width of the columns containing IDs to 1.  This
    // causes the columns to be small.
    for (int i=1; i<=MAX_TEAM_SIZE; i++)
      table.getColumn(table.getColumnName(i)).setPreferredWidth(1);
    // Likewise for the score columns
    table.getColumn(table.getColumnName(firstScoringColumn+1)).setPreferredWidth(1);
    table.getColumn(table.getColumnName(lastScoringColumn)).setPreferredWidth(1);
  }

  // Displays a summary of scores for the question.  Takes a double array
  // of the votes received and integers corresponding to incorrect
  // questions.  For example, if answer 3 was incorrect, the number 3
  // should be passed when this method is called.
  public void displayScoreSummary(Question question) {
    model.displayScoreSummary(question);
    repaint();
  }

  // Returns the team with the highest total score.
  public Team[] getWinner() {
    return model.getWinner();
  }

  // Returns the team with the most improvement
  public Team[] getMostImproved() {
    return model.getMostImproved();
  }
}

//  LocalWords:  UpopVote JTable ScoreboardModel
