package gui;

import static gui.RowColors.C1;
import static gui.RowColors.C2;
import static gui.RowColors.C3;
import static gui.RowColors.C4;
import static gui.UpopVote.MAX_TEAMS;

import java.awt.Color;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;

public enum Team {

  // The IDs listed below represent the IDs of the transmitters
  // organized by table as they physically appear in room
  // 26-152 at MIT.
  //
  // All teams must have the same number of players or MAX_TEAM_SIZE must be
  // modified.
  team0 (0, new int[] {106691, 106692, 106693, 106694, 106695, 106696, 106697, 106698, 106699}),
  team1 (1, new int[] {106700, 106701, 106702, 106703, 106704, 106705, 106706, 106707, 106708}),
  team2 (2, new int[] {106709, 106710, 106711, 106712, 106713, 106714, 106715, 106716, 106717}),
  team3 (3, new int[] {106718, 106719, 106720, 106721, 106722, 106723, 106724, 106725, 106726}),
  team4 (4, new int[] {106727, 106728, 106729, 106730, 106731, 106732, 106733, 106734, 106735}),
  team5 (5, new int[] {106736, 106737, 106738, 106739, 106740, 106741, 106742, 106743, 106744}),
  team6 (6, new int[] {106745, 106746, 106747, 106748, 106749, 106750, 106751, 106752, 106753}),
  team7 (7, new int[] {106754, 106755, 106756, 106757, 106758, 106759, 106760, 106761, 106762}),
  team8 (8, new int[] {106763, 106764, 106765, 106766, 106767, 106768, 106769, 106770, 106771}),
  team9 (9, new int[] {106772, 106773, 106774, 106775, 106776, 106777, 106778, 106779, 106780}),
  team10 (10, new int[] {106781, 106782, 106783, 106784, 106785, 106786, 106787, 106788, 106789}),
  team11 (11, new int[] {106790, 106791, 106792, 106793, 106794, 106795, 106796, 106797, 106798}),
  team12 (12, new int[] {106799, 106800, 106801, 106802, 106803, 106804, 106805, 106806, 106807});

  private static final Color[] rowColors = { C1, C2, C3, C4 };

  private static final String teamNamePath = "upopvote"+File.separator+"TeamNames.txt";
  private static String[] teamNames;

  private int[] ids;            // the complete transmitter ID
  // This isn't quite right:  the room has tables numbered 1-13, but the
  // code has tables numbered 0-12.
  private int number;            // the table number


  private Team(int number, int[] ids) {
    this.number = number;
    this.ids = ids;
  }

  public Color getRowColor() {
    return rowColors[getNumber() % rowColors.length];
  }

  public int getNumber() {
    return this.number;
  }

  public static Team getTeam(int number) {
    assert 0 <= number && number < Team.values().length
      : "Bad team number: " + number;
    return Team.values()[number];
  }

  // Make a copy of the private ids array.
  // This is rather inefficient.
  // I presume this is a defensive measure, to avoid representation exposure.
  public int[] getIDs() {
    int[] newIds = new int[ids.length];
    for (int i=0; i<ids.length; i++)
      newIds[i] = ids[i];
    return newIds;
  }

  public int getPlayerNumber(int id) {
    // assert that the return value is in the array at the
    // correct location
    int playerno = id - getIDs()[0];
    assert 0 <= playerno && playerno < getIDs().length
      : "Bad id " + id + " (playerno " + playerno + ", team " + number + ")";
    assert getIDs()[playerno] == id;

    return playerno;
  }

  public boolean isOnTeam(int i) {
    for (int j : getIDs())
      if (j == i)
        return true;
    return false;
  }

  public String toString() {
    if (teamNames!=null)
      return teamNames[number];
    else {
      teamNames = new String[MAX_TEAMS];
      // parse the teamName file
      String[] defaultTeamNames = new String[] {"Team 1","Team 2","Team 3","Team 4","Team 5","Team 6","Team 7","Team 8","Team 9","Team 10","Team 11","Team 12","Team 13"};
      int i=0;
      try {
        File teamNameFile = new File(teamNamePath);
        BufferedReader reader = new BufferedReader(new FileReader(teamNameFile));

        String teamName;
        for (i=0; i<MAX_TEAMS; i++) {
          teamName = reader.readLine().trim();
          teamNames[i] = teamName;
        }
      }
      catch (FileNotFoundException e1) {
        teamNames = defaultTeamNames;
      }
      catch (IOException e2) {
        while (i<MAX_TEAMS) {
          teamNames[i] = defaultTeamNames[i];
          i += 1;
        }
      }
    }
    // finally return the team name
    return teamNames[number];
  }

  public static Team findTeam(int id) {
    for (Team t : Team.values())
      for (int someID : t.getIDs())
        if (someID == id)
          return t;
    throw new RuntimeException("Cannot find ID: "+id+" on any team.");
  }
}

//  LocalWords:  upopvote TeamNames txt teamName
